@@ -2,6 +2,9 @@ use std::any::TypeId;
 use std::mem::MaybeUninit;
 use std::ptr::{NonNull, addr_of, null_mut};
 
+use xjbutil::wide_ptr::WidePointer;
+use xjbutil::void::Void;
+
 use crate::collections::test_container::{
     GenericTestContainer,
     TestContainer,
@@ -12,8 +15,6 @@ use crate::data::container::ContainerVT;
 use crate::data::traits::{ChildrenType, StaticBase};
 use crate::data::tyck::{TyckInfo, TyckInfoPool};
 use crate::data::wrapper::{Wrapper, WrapperData, DynBase, OwnershipInfo};
-use crate::util::mem::FatPointer;
-use crate::util::void::Void;
 
 #[allow(dead_code)]
 struct TestStruct {
@@ -269,7 +270,7 @@ impl StaticBase<TestStruct2> for Void {
             <Void as StaticBase<TestContainer<TestStruct2>>>::tyck_info(&mut tyck_info_pool);
         assert!(dyn_base.dyn_tyck(tyck_info.as_ref()));
 
-        let children: Vec<FatPointer> = dyn_base.children().unwrap().collect::<Vec<_>>();
+        let children: Vec<WidePointer> = dyn_base.children().unwrap().collect::<Vec<_>>();
         assert_eq!(children.len(), 2);
         assert_eq!(children[0], value1.ptr_repr);
         assert_eq!(children[1], value2.ptr_repr);
