@@ -2,12 +2,12 @@ use std::any::TypeId;
 use std::iter::Iterator;
 use std::ptr::NonNull;
 
-use xjbutil::fat_ptr::FatPointer;
 use xjbutil::void::Void;
+use xjbutil::wide_ptr::WidePointer;
 
 use crate::data::tyck::{TyckInfo, TyckInfoPool};
 
-pub type ChildrenType = Option<Box<dyn Iterator<Item=FatPointer> + 'static>>;
+pub type ChildrenType = Option<Box<dyn Iterator<Item=WidePointer> + 'static>>;
 
 pub trait StaticBase<T: 'static> {
     fn type_id() -> TypeId {
@@ -30,10 +30,7 @@ pub trait StaticBase<T: 'static> {
         std::any::type_name::<T>().into()
     }
 
-    // TODO: should we mark this as unsafe?
-    #[inline] fn children(_vself: *const T) -> ChildrenType {
-        None
-    }
+    #[inline] fn children(_vself: *const T) -> ChildrenType { None }
 }
 
 // impl !StaticBase<i64> for Void {}
