@@ -15,7 +15,7 @@ use crate::data::wrapper::{
 use crate::ffi::{FFIException, Signature};
 use crate::util::serializer::Serializer;
 
-pub trait AsyncVMContext: 'static + Sized + Send + Sync {
+pub trait AsyncVMContext: VMContext + Send + Sync {
     type SharedData;
 
     fn serializer(&self) -> &Serializer<Self::SharedData>;
@@ -129,11 +129,13 @@ pub struct Promise {
     pub guard: PromiseGuard
 }
 
-impl Promise {
-    pub async fn await_promise(self) -> AsyncReturnType {
-        let fut: Pin<Box<dyn Future<Output=AsyncReturnType> + Send + 'static>> = self.fut;
-        let result: AsyncReturnType = fut.await;
-        result
+impl Unpin for Promise {}
+
+impl Future for Promise {
+    type Output = AsyncReturnType;
+
+    fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
+        Pin::into_inner(self).fut.poll_unpin(cx)
     }
 }
 
@@ -151,6 +153,9 @@ pub use crate::ffi::sync_fn::{
     value_move_out_check,
     value_move_out_check_norm
 };
+use std::task::{Context, Poll};
+use futures::FutureExt;
+use crate::ffi::sync_fn::VMContext;
 
 #[inline] pub unsafe fn value_into_ref<'a, T>(
     value: Value
