@@ -1,5 +1,5 @@
-use xjbutil::fat_ptr::FatPointer;
 use xjbutil::void::Void;
+use xjbutil::wide_ptr::WidePointer;
 
 use crate::data::Value;
 use crate::data::container::ContainerRef;
@@ -14,8 +14,8 @@ use crate::data::wrapper::{
 use crate::ffi::{FFIException, Signature};
 
 pub trait VMContext: 'static + Sized {
-    fn allocate(&mut self, fat_ptr: FatPointer);
-    fn mark(&mut self, fat_ptr: FatPointer);
+    fn allocate(&mut self, wide_ptr: WidePointer);
+    fn mark(&mut self, wide_ptr: WidePointer);
 }
 
 pub trait FunctionBase: 'static {
