@@ -1,9 +1,10 @@
-use crate::util::location::{SingleLineRange, SourceLoc, MultiLineRange};
+use crate::diag::location::{SourceLoc, SourceRange};
 
 pub struct AttrList {
     pub attributes: Vec<Attribute>,
 
     pub sharp_loc: SourceLoc,
+    pub exclaim_loc: SourceLoc,
     pub left_bracket_loc: SourceLoc,
     pub right_bracket_loc: SourceLoc
 }
@@ -21,7 +22,7 @@ pub struct KeyValuePairAttr {
     pub key: String,
     pub value: AttrValue,
 
-    pub key_range: SingleLineRange
+    pub key_range: SourceRange
 }
 
 pub enum AttrValue {
@@ -33,17 +34,17 @@ pub enum AttrValue {
 
 pub struct AttrIntValue {
     pub value: i64,
-    pub value_range: SingleLineRange
+    pub value_range: SourceRange
 }
 
 pub struct AttrIdentifierValue {
     pub value: String,
-    pub value_range: SingleLineRange
+    pub value_range: SourceRange
 }
 
 pub struct AttrStrValue {
     pub value: String,
-    pub value_range: MultiLineRange
+    pub value_range: SourceRange
 }
 
 pub struct AttrListValue {
