@@ -1,4 +1,5 @@
-use crate::util::location::{SingleLineRange, SourceLoc};
+use crate::diag::location::{SourceLoc, SourceRange};
+use crate::syntax::id::Identifier;
 
 pub enum ConcreteType {
     SimpleType(ConcreteSimpleType),
@@ -7,7 +8,7 @@ pub enum ConcreteType {
 
 pub struct ConcreteSimpleType {
     pub content: ConcreteSimpleTypeContent,
-    pub range: SingleLineRange
+    pub range: SourceRange
 }
 
 pub enum ConcreteSimpleTypeContent {
@@ -18,10 +19,11 @@ pub enum ConcreteSimpleTypeContent {
     CharType,
     StringType,
     DeducedType,
-    UserType(String)
+    UserType(Identifier)
 }
 
 pub struct ConcreteGenericType {
+    pub base: Identifier,
     pub inner: Box<ConcreteType>,
     pub left_angle: SourceLoc,
     pub right_angle: SourceLoc
