@@ -207,7 +207,9 @@ unsafe impl<SD: 'static> Sync for Serializer<SD> {}
 #[cfg(test)]
 mod test {
     use std::time::Duration;
-    use crate::util::async_utils::{block_on_future, testing_sleep};
+
+    use xjbutil::async_utils::{block_on_future, testing_sleep};
+
     use crate::util::serializer::Serializer;
 
     #[test]
