@@ -1,10 +1,10 @@
-use xjbutil::fat_ptr::FatPointer;
+use xjbutil::wide_ptr::WidePointer;
 
 use crate::vm::al31f::alloc::Alloc;
 use crate::vm::al31f::stack::Stack;
 
 pub struct NoGCAlloc {
-    managed: Vec<FatPointer>
+    managed: Vec<WidePointer>
 }
 
 impl NoGCAlloc {
@@ -17,7 +17,7 @@ impl NoGCAlloc {
 
 impl Drop for NoGCAlloc {
     fn drop(&mut self) {
-        for _fat_ptr /*: &FatPointer*/ in self.managed.iter() {
+        for _wide_ptr /*: &WidePointer*/ in self.managed.iter() {
             todo!()
         }
     }
@@ -28,11 +28,11 @@ impl Alloc for NoGCAlloc {
 
     #[inline(always)] unsafe fn remove_stack(&mut self, _stack: *const Stack) {}
 
-    unsafe fn add_managed(&mut self, data: FatPointer) {
+    unsafe fn add_managed(&mut self, data: WidePointer) {
         self.managed.push(data);
     }
 
-    #[inline(always)] unsafe fn mark_object(&mut self, _data: FatPointer) {}
+    #[inline(always)] unsafe fn mark_object(&mut self, _data: WidePointer) {}
 
     #[inline(always)] unsafe fn collect(&mut self) {}
 
