@@ -1,9 +1,11 @@
 use std::any::TypeId;
+use std::future::Future;
 use std::ptr::NonNull;
 
 use unchecked_unwrap::UncheckedUnwrap;
 use xjbutil::either::Either;
-use xjbutil::fat_ptr::FatPointer;
+use xjbutil::unchecked::{UncheckedSendFut, UncheckedSendSync};
+use xjbutil::wide_ptr::WidePointer;
 
 use crate::collections::object::Object;
 use crate::data::Value;
@@ -50,9 +52,6 @@ use crate::vm::al31f::stack::{FrameInfo, Stack, StackSlice};
 #[cfg(feature = "async")] use crate::ffi::async_fn::{AsyncReturnType, Promise};
 #[cfg(feature = "async")] use crate::ffi::async_fn::AsyncFunction as FFIAsyncFunction;
 #[cfg(feature = "async")] use crate::util::serializer::Serializer;
-#[cfg(feature = "async")] use crate::vm::al31f::AsyncCombustor;
-
-#[cfg(feature = "bench")] use xjbutil::defer::Defer;
 #[cfg(feature = "bench")] use xjbutil::defer;
 
 include!("get_vm_makro.rs");
@@ -149,7 +148,7 @@ unsafe fn checked_exception_unwind_stack<A: Alloc>(
     Err(exception)
 }
 
-pub async unsafe fn vm_thread_run_function<A: Alloc>(
+async unsafe fn vm_thread_run_function_impl<A: Alloc>(
     thread: &mut VMThread<A>,
     func_id: usize,
     args: &[Value]
@@ -246,8 +245,8 @@ pub async unsafe fn vm_thread_run_function<A: Alloc>(
                 slice.set_value(*dst, Value::new_bool(src1 == src2));
             },
             Insc::EqAny(src1, src2, dst) => {
-                let src1: FatPointer = slice.get_value(*src1).ptr_repr;
-                let src2: FatPointer = slice.get_value(*src2).ptr_repr;
+                let src1: WidePointer = slice.get_value(*src1).ptr_repr;
+                let src2: WidePointer = slice.get_value(*src2).ptr_repr;
                 slice.set_value(*dst, Value::new_bool(src1 == src2));
             },
             Insc::NeValue(src1, src2, dst) => {
@@ -263,8 +262,8 @@ pub async unsafe fn vm_thread_run_function<A: Alloc>(
                 slice.set_value(*dst, Value::new_bool(src1 != src2));
             },
             Insc::NeAny(src1, src2, dst) => {
-                let src1: FatPointer = slice.get_value(*src1).ptr_repr;
-                let src2: FatPointer = slice.get_value(*src2).ptr_repr;
+                let src1: WidePointer = slice.get_value(*src1).ptr_repr;
+                let src2: WidePointer = slice.get_value(*src2).ptr_repr;
                 slice.set_value(*dst, Value::new_bool(src1 != src2));
             },
             Insc::LtInt(src1, src2, dst) =>
@@ -462,7 +461,7 @@ pub async unsafe fn vm_thread_run_function<A: Alloc>(
                 }
                 ffi_rets.set_len(ret_value_locs.len());
 
-                let mut combustor: Combustor<A> = Combustor::new(NonNull::from(get_vm!(thread)));
+                let mut combustor: Combustor<A> = Combustor::new(NonNull::from(&mut thread.vm));
 
                 if let Err(e /*: FFIException*/) =
                     ffi_function.call_tyck(&mut combustor, &ffi_args, &mut ffi_rets)
@@ -505,7 +504,7 @@ pub async unsafe fn vm_thread_run_function<A: Alloc>(
                 }
                 ffi_rets.set_len(ret_value_locs.len());
 
-                let mut combustor: Combustor<A> = Combustor::new(NonNull::from(get_vm!(thread)));
+                let mut combustor: Combustor<A> = Combustor::new(NonNull::from(&mut thread.vm));
 
                 if let Err(e /*: FFIException*/) =
                     ffi_function.call_rtlc(&mut combustor, &ffi_args, &mut ffi_rets)
@@ -535,7 +534,7 @@ pub async unsafe fn vm_thread_run_function<A: Alloc>(
             Insc::FFICallAsyncTyck(_, _, _) => {}
             #[cfg(all(feature = "optimized-rtlc", feature = "async"))]
             Insc::FFICallAsync(async_ffi_func_id, args, ret) => {
-                let async_ffi_function: &Box<dyn FFIAsyncFunction<AsyncCombustor<A>>>
+                let async_ffi_function: &Box<dyn FFIAsyncFunction<Combustor<A>>>
                     = &program.async_ffi_funcs[*async_ffi_func_id];
 
                 for i /*: usize*/ in 0..args.len() {
@@ -544,7 +543,7 @@ pub async unsafe fn vm_thread_run_function<A: Alloc>(
                 }
                 ffi_args.set_len(args.len());
 
-                let mut combustor: AsyncCombustor<A> = AsyncCombustor::new(
+                let mut combustor: Combustor<A> = Combustor::new(
                     NonNull::from(&thread.vm)
                 );
 
@@ -594,7 +593,7 @@ pub async unsafe fn vm_thread_run_function<A: Alloc>(
                 let promise: Promise = promise.move_out::<Promise>();
                 (*wrapper).ownership_info = OwnershipInfo::MovedToRust as u8;
 
-                let AsyncReturnType(result) = thread.vm.co_await(promise.await_promise()).await;
+                let AsyncReturnType(result) = thread.vm.co_await(promise).await;
                 match result {
                     Ok(values) => {
                         debug_assert_eq!(values.len(), dests.len());
@@ -680,3 +679,10 @@ pub async unsafe fn vm_thread_run_function<A: Alloc>(
         }
     }
 }
+
+pub unsafe fn vm_thread_run_function<'a, A: Alloc>(
+    arg_pack: UncheckedSendSync<(&'a mut VMThread<A>, usize, &'a [Value])>
+) -> impl Future<Output=Result<Vec<Value>, Exception>> + Send + Unpin + 'a {
+    let (thread, func_id, args): (&mut VMThread<A>, usize, &[Value]) = arg_pack.into_inner();
+    UncheckedSendFut::new(vm_thread_run_function_impl(thread, func_id, args))
+}
