@@ -1,11 +1,13 @@
 use std::any::TypeId;
 
+use xjbutil::async_utils::block_on_future;
+use xjbutil::unchecked::UncheckedSendSync;
+
 use crate::collections::object::Object;
 use crate::data::Value;
 use crate::data::exception::Exception;
 use crate::data::wrapper::DynBase;
 use crate::data::value_typed::{VALUE_TYPE_TAG_MASK, ValueTypeTag};
-use crate::util::async_utils::block_on_future;
 use crate::vm::al31f::alloc::default_alloc::DefaultAlloc;
 use crate::vm::al31f::compiled::CompiledProgram;
 use crate::vm::al31f::executor::{VMThread, create_vm_main_thread, vm_thread_run_function};
@@ -24,8 +26,10 @@ async fn basic_program_eval() {
     let alloc: DefaultAlloc = DefaultAlloc::new();
 
     let mut vm_thread: Box<VMThread<DefaultAlloc>> = create_vm_main_thread(alloc, &program).await;
+    let arg_pack: (&mut VMThread<DefaultAlloc>, usize, &[Value])
+        = (&mut vm_thread, 0, &[Value::new_int(114), Value::new_int(514)]);
     let result: Result<Vec<Value>, Exception> = unsafe {
-        vm_thread_run_function(&mut vm_thread, 0, &[Value::new_int(114), Value::new_int(514)]).await
+        vm_thread_run_function(UncheckedSendSync::new(arg_pack)).await
     };
     if let Ok(result /*: Vec<Value>*/) = result {
         assert_eq!(result.len(), 1);
@@ -42,12 +46,12 @@ async fn basic_program_eval() {
 
 async fn basic_fn_call() {
     let program: CompiledProgram<DefaultAlloc> = basic_fn_call_program::<>();
-
     let alloc: DefaultAlloc = DefaultAlloc::new();
 
     let mut vm_thread: Box<VMThread<DefaultAlloc>> = create_vm_main_thread(alloc, &program).await;
+    let arg_pack: (&mut VMThread<DefaultAlloc>, usize, &[Value]) = (&mut vm_thread, 0, &[]);
     let result: Result<Vec<Value>, Exception> = unsafe {
-        vm_thread_run_function(&mut vm_thread, 0, &[]).await
+        vm_thread_run_function(UncheckedSendSync::new(arg_pack)).await
     };
     if let Ok(result /*: Vec<Value>*/) = result {
         assert_eq!(result.len(), 1);
@@ -68,8 +72,10 @@ async fn fibonacci_call() {
 
     let mut vm_thread: Box<VMThread<DefaultAlloc>> =
         create_vm_main_thread(alloc, &fib_program).await;
+    let arg_pack: (&mut VMThread<DefaultAlloc>, usize, &[Value]) =
+        (&mut vm_thread, 0, &[Value::new_int(7)]);
     let result: Result<Vec<Value>, Exception> = unsafe {
-        vm_thread_run_function(&mut vm_thread, 0, &[Value::new_int(7)]).await
+        vm_thread_run_function(UncheckedSendSync::new(arg_pack)).await
     };
     if let Ok(result /*: Vec<Value>*/) = result {
         assert_eq!(result.len(), 1);
@@ -90,8 +96,9 @@ async fn exception_no_eh_call() {
 
     let mut vm_thread: Box<VMThread<DefaultAlloc>> =
         create_vm_main_thread(alloc, &exception_no_eh_program).await;
+    let arg_pack: (&mut VMThread<DefaultAlloc>, usize, &[Value]) = (&mut vm_thread, 0, &[]);
     let result: Result<Vec<Value>, Exception> = unsafe {
-        vm_thread_run_function(&mut vm_thread, 0, &[]).await
+        vm_thread_run_function(UncheckedSendSync::new(arg_pack)).await
     };
 
     if let Err(e /*: Exception*/) = result {
@@ -114,9 +121,11 @@ async fn exception_call() {
 
     let mut vm_thread: Box<VMThread<DefaultAlloc>> =
         create_vm_main_thread(alloc, &exception_program).await;
+    let arg_pack: (&mut VMThread<DefaultAlloc>, usize, &[Value]) = (&mut vm_thread, 0, &[]);
     let result: Result<Vec<Value>, Exception> = unsafe {
-        vm_thread_run_function(&mut vm_thread, 0, &[]).await
+        vm_thread_run_function(UncheckedSendSync::new(arg_pack)).await
     };
+
     if let Ok(result /*: Vec<Value>*/) = result {
         assert_eq!(result.len(), 1);
         assert!(result[0].is_value());
@@ -136,8 +145,9 @@ async fn ffi_call() {
 
     let mut vm_thread: Box<VMThread<DefaultAlloc>> =
         create_vm_main_thread(alloc, &ffi_call_program).await;
+    let arg_pack: (&mut VMThread<DefaultAlloc>, usize, &[Value]) = (&mut vm_thread, 0, &[]);
     let result: Result<Vec<Value>, Exception> = unsafe {
-        vm_thread_run_function(&mut vm_thread, 0, &[]).await
+        vm_thread_run_function(UncheckedSendSync::new(arg_pack)).await
     };
     if let Ok(result /*: Vec<Value>*/) = result {
         assert_eq!(result.len(), 0);
@@ -152,12 +162,10 @@ async fn ffi_call2() {
 
     let mut vm_thread: Box<VMThread<DefaultAlloc>> =
         create_vm_main_thread(alloc, &ffi_call_program).await;
+    let arg_pack: (&mut VMThread<DefaultAlloc>, usize, &[Value]) =
+        (&mut vm_thread, 0, &[Value::new_int(114), Value::new_int(514)]);
     let result: Result<Vec<Value>, Exception> = unsafe {
-        vm_thread_run_function(
-            &mut vm_thread,
-            0,
-            &[Value::new_int(114), Value::new_int(514)]
-        ).await
+        vm_thread_run_function(UncheckedSendSync::new(arg_pack)).await
     };
     if let Ok(result /*: Vec<Value>*/) = result {
         assert_eq!(result.len(), 1);
